@@ -1,7 +1,7 @@
 from rest_framework import serializers
 
 from netbox.api.serializers import WritableNestedSerializer
-from netbox_storage.models import Filesystem, Drive, Partition, PhysicalVolume
+from netbox_storage.models import Filesystem, Drive, Partition, PhysicalVolume, VolumeGroup
 
 
 #
@@ -66,5 +66,5 @@ class NestedVolumeGroupSerializer(WritableNestedSerializer):
     )
 
     class Meta:
-        model = PhysicalVolume
+        model = VolumeGroup
         fields = ["id", "url", "display", "vg_name"]
