@@ -17,8 +17,8 @@ class RelatedDrives(PluginTemplateExtension):
         # )
         # volumes = LinuxVolume.objects.all()
         # exclude_drive_id = []
-        # for volume in volumes.all():
-        #     for drive in volume.drives.all():
+        # for inc in volumes.all():
+        #     for drive in inc.drives.all():
         #         exclude_drive_id.append(drive.id)
         # unmapped_drives = Drive.objects.filter(
         #     virtual_machine=obj
@@ -26,8 +26,8 @@ class RelatedDrives(PluginTemplateExtension):
 
         # all_volumes = LinuxVolume.objects.all()
         # display_volume = []
-        # for volume in all_volumes:
-        #     display_volume = volume.drives.all().intersection(drives)
+        # for inc in all_volumes:
+        #     display_volume = inc.drives.all().intersection(drives)
         display_partition = []
         for drive in drives:
             display_partition = Partition.objects.filter(
@@ -38,7 +38,7 @@ class RelatedDrives(PluginTemplateExtension):
         if platform is not None:
             if platform.name.lower().__contains__('windows'):
                 return self.render(
-                    "netbox_storage/volume/windowsvolume_box.html",
+                    "netbox_storage/inc/windowsvolume_box.html",
                     extra_context={
                         # "volumes": volumes,
                         # "unmapped_drives": unmapped_drives,
@@ -48,14 +48,14 @@ class RelatedDrives(PluginTemplateExtension):
                 )
             elif platform.name.lower().__contains__('linux'):
                 return self.render(
-                    "netbox_storage/volume/linuxvolume_box.html",
+                    "netbox_storage/inc/linuxvolume_box.html",
                     extra_context={
                         "partitions": display_partition,
                     },
                 )
         else:
             return self.render(
-                "netbox_storage/volume/unknown_os_box.html",
+                "netbox_storage/inc/unknown_os_box.html",
             )
 
 
